@@ -7,7 +7,7 @@ port = 8000
 def open_browser():
       webbrowser.open_new('http://127.0.0.1:{0}/'.format(port))
 
-if __name__ == "__main__":
+def main():
     websocketServer = WebSocketServer(
         ('', port),
         Resource(OrderedDict([('/', HHLPyApplication)]))
@@ -25,3 +25,6 @@ if __name__ == "__main__":
         print("KeyboardInterrupt")
         print("Closing python websocket server")
         websocketServer.stop()
+
+if __name__ == "__main__":
+    main()
\ No newline at end of file
